@@ -44,7 +44,7 @@ docker = Config.docker_client
 ### function to init the scan and will check the docker is in place
 def init():
 
-    print('New Scan has been Initiated')
+    logging.info('New Scan has been Initiated')
     logging.info('Checking for Docker in the Env')
     try:
         #docker = docker.from_env()
@@ -97,7 +97,13 @@ def runImage(data=None,type=None):
         gid = os.getgid()
 
 
-        userid= f"{uid}:{gid}"
+        if Config.jenkins == 'yes':
+            logging.info('Checking user permission for jenkins environment')
+            userid = 'root'
+        else:
+            logging.info('Checking user permission')
+            userid= f"{uid}:{gid}"
+
     except:
         userid= 'root'
 
@@ -175,10 +181,26 @@ def runImage(data=None,type=None):
 
                 
             else:
-                Config.build_dir = Config.sast_build_dir
-                container_output = docker.containers.run(docker_image, command_line, volumes={Config.sast_build_dir: {
-                            'bind': data['bind']}}, user=userid,detach=detach,environment=env_var)
-                logging.info('[SUCCESS]: %s Scan Completed',tool_name)
+
+
+                if Config.jenkins == 'yes':
+
+                    logging.info('Preparing %s scan for jenkins env with %s user ', tool_name , userid)    
+
+                    Config.build_dir = Config.sast_build_dir
+                    container_output = docker.containers.run(docker_image, command_line, volumes={Config.sast_build_dir: {
+                                'bind': data['bind']}}, user=userid,detach=detach,environment=env_var)
+                    logging.info('[SUCCESS]: %s Scan Completed',tool_name)
+
+
+                else:    
+
+                    logging.info('Preparing %s scan for non jenkins env with %s user ', tool_name ,userid)
+
+                    Config.build_dir = Config.sast_build_dir
+                    container_output = docker.containers.run(docker_image, command_line, volumes={Config.sast_build_dir: {
+                                'bind': data['bind']}}, user=userid,detach=detach,environment=env_var)
+                    logging.info('[SUCCESS]: %s Scan Completed',tool_name)
 
             
 
@@ -266,21 +288,61 @@ def runImage(data=None,type=None):
                 command_line = "% s" % command_line.format(target_url = target_url, api_type=api_type)
             else:
                 command_line = "% s" % command_line.format(target_url = target_url)
-            #print(command_line)
-        try:
-            Config.build_dir = Config.sast_build_dir
-            container= docker.containers.run(docker_image, command_line, volumes={Config.sast_build_dir: {
- 			 	'bind': data['bind'], 'mode': 'rw'}},user=userid,detach=detach)
 
-            #print(output_file,toolname,tool_id,scan_details_id)
-            logging.info('[SUCCESS]: %s Scan Completed',tool_name)
-            Config.dast_scan_status ='Completed'
-        except errors.ContainerError as exc:
-            Config.dast_scan_status ='Completed'
-            logging.error('[ERROR]: Error recorded while Scanning %s',tool_name)
-            Config.dast_errors = 'Error recorded while Scanning',tool_name, '[',str(exc),']'
-            msg='\n The following error has been recorded while scanning DAST'
-            Utils.logError(msg,str(exc))
+            #print(command_line)
+
+
+            ## context file appending -- MM
+
+   #         if Config.zap_context_configured == 'true':
+
+    #            context_file_name = Config.zap_context_file_nmae
+     #           context_command = Config.zap_context_cmd
+      #          command_line = "% s" % command_line.format(context_file = context_file_name)
+
+
+
+        ## part where running dast based on the given env i.e jenkins or non jenkins
+
+
+
+        if Config.jenkins == 'yes':
+
+            logging.info('Preparing %s scan for jenkins environment as user %s ',tool_name, userid)       
+
+            try:
+                Config.build_dir = Config.sast_build_dir
+                container= docker.containers.run(docker_image, command_line, volumes={Config.sast_build_dir: {
+                    'bind': data['bind'], 'mode': 'rw'}},user=userid,detach=detach)
+
+                #print(output_file,toolname,tool_id,scan_details_id)
+                logging.info('[SUCCESS]: %s Scan Completed',tool_name)
+                Config.dast_scan_status ='Completed'
+            except errors.ContainerError as exc:
+                Config.dast_scan_status ='Completed'
+                logging.error('[ERROR]: Error recorded while Scanning %s',tool_name)
+                Config.dast_errors = 'Error recorded while Scanning',tool_name, '[',str(exc),']'
+                msg='\n The following error has been recorded while scanning DAST'
+                Utils.logError(msg,str(exc))
+
+        else:    
+
+            logging.info('Preparing %s scan for non-jenkins environment with user %s',tool_name, userid)  
+
+            try:
+                Config.build_dir = Config.sast_build_dir
+                container= docker.containers.run(docker_image, command_line, volumes={Config.sast_build_dir: {
+                    'bind': data['bind'], 'mode': 'rw'}},user=userid,detach=detach)
+
+                #print(output_file,toolname,tool_id,scan_details_id)
+                logging.info('[SUCCESS]: %s Scan Completed',tool_name)
+                Config.dast_scan_status ='Completed'
+            except errors.ContainerError as exc:
+                Config.dast_scan_status ='Completed'
+                logging.error('[ERROR]: Error recorded while Scanning %s',tool_name)
+                Config.dast_errors = 'Error recorded while Scanning',tool_name, '[',str(exc),']'
+                msg='\n The following error has been recorded while scanning DAST'
+                Utils.logError(msg,str(exc))
 
 
 
@@ -563,7 +625,7 @@ def main():
                 logging.info('No SAST Configuration found from SaaS')    
                 logging.info('Ignoring SAST Scan')
             else:
-                print(data)
+                #print(data)
                 logging.info('SAST data found %s',type(data)) 
                 runImage(data=data,type='SAST')
 
@@ -606,7 +668,7 @@ def main():
         
         for data in Config.sca_response:
 
-            if data['status'] == 0 :   
+            if data['scan_status'] == 0 :   
                 logging.info('No SCA Configuration found  from SaaS')    
                 logging.info('Ignoring SCA Scan')
             else:
@@ -625,11 +687,12 @@ def main():
 
 def default():
 
-    parser.add_argument('-a','--action',default='init',help="Action arugment, you need to pass the value for action (eg: test-saas, test-docker, run)")
+    parser.add_argument('-a','--action',default='init',help="Action arugment, you need to pass the value for action (eg: test-saas, test-docker, run , test-yaml, version, check-user)")
     parser.add_argument('-u','--url',default='https://dashboard.boman.ai/v2/',help="Provide the URL of the boman saas (eg: Prod, On-prem)")
-    parser.add_argument('-v','--version',default='show',help="will show the version of boman-cli tool",action='store_true')
-    parser.add_argument('-fb','--failBuild',default='pass',help="this is the default value exit code in boman, pass fail if you want to fail the build when boman successfully runs the scan")
-    #parser.add_argument('-check-docker',help='Check you docker is present in your system is compatable to run the boman.ai')
+    parser.add_argument('-v','--version',default='show',help="Will show the version of boman-cli tool",action='store_true')
+    parser.add_argument('-fb','--failBuild',default='pass',help="This is for failing the boman scan, pass value 'fail' if you want to fail the build when boman successfully runs the scan")
+    parser.add_argument('-cicd','--cicd',default='other',help="Pass jenkins if the cicd you are using is jenkins (value: jenkins). if your are using non-jenkins cicd you can ignore this option.")
+    #parser.add_argument('-check-docker',help='Check you docker is present in your system is compatable to run the boma n.ai')
     args = parser.parse_args()
 
     # if len(sys.args) == 1:
@@ -643,7 +706,14 @@ def default():
         Config.boman_url = args.url   
 
 
+    ## cicd argument
 
+    if args.cicd == 'jenkins':
+        ##logging.info('jenkins is choosen')
+        Config.jenkins = 'yes'
+    else:
+        ###logging.info('jenkins is not choosen')
+        Config.jenkins = 'no'  
 
 
 ## Action argument
@@ -678,6 +748,25 @@ def default():
     elif args.action =='test-yaml':
        Validation.yamlValidation()
        exit(0)
+
+    elif args.action == 'version':
+       print('boman-cli-uat',Config.version)
+       exit(0)
+    elif args.action == 'check-user':
+       
+       print('User:', os.getlogin())
+       print('UID:', os.getuid())
+       print('GID:', os.getgid())
+       print('------------------')
+       current_work_dir = os.getcwd()+'/'
+       print('Access for :', current_work_dir)
+       print('READ:', os.access(current_work_dir, os.R_OK))
+       print('WRITE:',os.access(current_work_dir, os.W_OK))
+       print('EXECUTION:',os.access(current_work_dir, os.X_OK))
+       print('WRITE FILE IN DIR:',os.access(current_work_dir, os.X_OK | os.W_OK))
+       print('------------------')
+       exit(0)   
+
     else:
         print('Welcome to Boman CLI',Config.version,',pass bomancli --help to view the commands args ')
         exit(0)
