@@ -32,7 +32,7 @@ def checkImageAlreadyExsist(imagename):
     except Exception as e:
         logging.error('Docker throwing a error , please check the docker installation')
         #print(str(e))
-        exit(-1)
+        exit(3) ## docker/system error
 
     for image in image_list:
        #print(image.tags)
@@ -48,7 +48,7 @@ def checkImageAlreadyExsist(imagename):
         return 1
     except:
         logging.error('Error pulling the image [%s]',imagename)
-        exit(-1)
+        exit(3) ## docker/system error
 
             
 
@@ -77,13 +77,14 @@ def testServer():
     except requests.ConnectionError as e:
         print(e)
         logging.error("Can't connect to the Server, Please check your Internet connection.")
+        exit(1) #server/saas error
     else:
         if str(x.content):
             logging.info("Server is reachable ")
             return 1
         else:
             logging.error("Boman.ai Server is not reachable")	
-            exit(-1)
+            exit(1) ## docker/system error
 
 
 
@@ -99,7 +100,7 @@ def testDockerAvailable():
     except Exception as e:
         logging.error('Docker not found in your machine, Please install docker to continue the scanning')
         #print(str(e))
-        exit(-1)
+        exit(3) ## docker/system error
 
 
 
@@ -123,7 +124,7 @@ def testDastUrl(url):
         #     return 1
         # else:
         #     logging.error("Boman.ai Server is not reachable")	
-        #     exit(-1)
+        #     exit(3)
 
 
 
@@ -138,7 +139,11 @@ def getLoc(build_dir,lang):
         'php':'.php',
         'ruby':'.rb',
         'go':'.go',
-        'java':'.java'
+        'java':'.java',
+        'python-snyk':'.py',
+        'node-snyk':'.js',
+        'ruby-snyk':'.rb',
+        'csharp':'.cs'
     }
 
     #print(lang_extensions['js'])
@@ -232,8 +237,8 @@ def logError(msg,error):
 
 def showSummary():
     logging.info('---------------------------------------------------------------------------------------------------------------')
-    logging.info('--------------------------  SUMMARY FOR SCAN: %s  -----------------------------------------------',Config.scan_name)
-    logging.info('---------------------------------------------------------------------------------------------------------------')
+    logging.info('--------------------------  SUMMARY FOR SCAN: %s  -----------------------------------------------',Config.scan_name,)
+    logging.info('--------------------------- Scan Token: %s --------------------------------------------------------',Config.scan_token)
 
     logging.info('-------- SAST STATUS ---------')
     if Config.sast_present == True:
@@ -284,7 +289,15 @@ def showSummary():
     logging.info('-------------------------------------')
 
 
+
+
     # logging.info(Config.sast_message)
     # logging.info(Config.dast_message)
     # logging.info(Config.sca_message)
     # logging.info(Config.secret_scan_message)
+
+
+
+def uploadLogs():
+    logging.info('Uploading logs for the scan token %s',str(Config.scan_token))
+    return 1
\ No newline at end of file
